=======
History
=======

1.1.1 (2020-11-18)
------------------

* Support Python 3.9.
* Add a hint on how to enable writes in the ``DjangoReadOnlyError`` message.

1.1.0 (2020-10-08)
------------------

* Add support for a ``DJANGO_READ_ONLY`` setting, to allow finer grained
  customization of when read-only mode is enabled.

1.0.0 (2020-10-01)
------------------

* Initial release.
